@@ -1,11 +1,13 @@
 package Google::Adwords::AdGroupEstimate;
+use strict;
+use warnings;
 
 use base 'Google::Adwords::Data';
 
 my @fields = qw/
     id
     keywordEstimates
-/;
+    /;
 
 __PACKAGE__->mk_accessors(@fields);
 
@@ -50,7 +52,7 @@ Rohan Almeida <rohan@almeida.in>
 
  
  
-=head1 LICENCE AND COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
  
 Copyright (c) 2006 Rohan Almeida <rohan@almeida.in>. All rights
 reserved.
