@@ -4,6 +4,7 @@ use base qw/ Data /;
 use Test::More;
 
 use Google::Adwords::BudgetOptimizerSettings;
+use Google::Adwords::ConversionOptimizerSettings;
 
 sub test_class { return "Google::Adwords::Campaign"; }
 
@@ -13,10 +14,10 @@ sub accessors : Test(no_plan)
 
     my $campaign = $self->{'obj'};
 
-    $self->{'obj'}->dailyBudget(100);
+    $self->{'obj'}->budgetAmount(100);
     $self->{'obj'}->name('Campaign #9');
 
-    ok( $self->{'obj'}->dailyBudget == 100, 'daily_budget' );
+    ok( $self->{'obj'}->budgetAmount == 100, 'budgetAmount' );
     ok( $self->{'obj'}->name eq 'Campaign #9', 'name' );
 
     # budget optimizer
@@ -34,6 +35,24 @@ sub accessors : Test(no_plan)
     ok( $self->{obj}->budgetOptimizerSettings->bidCeiling eq '100',
         'budgetOptimizerSettings bidCeiling' );
 
+    # conversion optimizer
+    my $conversion_opt = Google::Adwords::ConversionOptimizerSettings->new();
+    $conversion_opt->maxCpaBidForAllAdGroups(100);
+    $conversion_opt->enabled('true');
+
+    $self->{obj}->conversionOptimizerSettings($conversion_opt);
+
+    ok(
+        ref $self->{obj}->conversionOptimizerSettings eq
+            'Google::Adwords::ConversionOptimizerSettings',
+        'conversionOptimizerSettings'
+    );
+    ok(
+        $self->{obj}->conversionOptimizerSettings->maxCpaBidForAllAdGroups eq
+            '100',
+        'conversionOptimizerSettings maxCpaBidForAllAdGroups'
+    );
+
     # bug id 33
     $campaign->name('Me & You');
     ok( $campaign->name eq 'Me & You', 'bug id 33' );
